Struct ZwpXwaylandKeyboardGrabManagerV1

pub struct ZwpXwaylandKeyboardGrabManagerV1 { /* private fields */ }
Available on crate feature wayland and Linux only.
context object for keyboard grab manager

A global interface used for grabbing the keyboard.

This interface has no events.

Implementations



impl ZwpXwaylandKeyboardGrabManagerV1

pub fn destroy(&self)

destroy the keyboard grab manager

Destroy the keyboard grab manager.

pub fn grab_keyboard<U, D>( &self, surface: &WlSurface, seat: &WlSeat, qh: &QueueHandle<D>, udata: U, ) -> ZwpXwaylandKeyboardGrabV1
where U: Send + Sync + 'static, D: Dispatch<ZwpXwaylandKeyboardGrabV1, U> + 'static,

grab the keyboard to a surface

The grab_keyboard request asks for a grab of the keyboard, forcing the keyboard focus for the given seat upon the given surface.

The protocol provides no guarantee that the grab is ever satisfied, and does not require the compositor to send an error if the grab cannot ever be satisfied. It is thus possible to request a keyboard grab that will never be effective.

The protocol:

  • does not guarantee that the grab itself is applied for a surface, the grab request may be silently ignored by the compositor,
  • does not guarantee that any events are sent to this client even if the grab is applied to a surface,
  • does not guarantee that events sent to this client are exhaustive, a compositor may filter some events for its own consumption,
  • does not guarantee that events sent to this client are continuous, a compositor may change and reroute keyboard events while the grab is nominally active.